==> jc-1.4.0.tar.gz: java/io/FileDescriptor.h <==
// public final class java.io.FileDescriptor

// class file dependencies
// @dep_class 410fd3c919444a2c java_io_FileDescriptor
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_io_FileDescriptor_H_
#define _JC_java_io_FileDescriptor_H_

// Forward structure declarations
struct _jc_java_io_FileDescriptor$object;
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_ByteChannel$object;

// Typedefs
typedef struct _jc_java_io_FileDescriptor$sub_refs	_jc_java_io_FileDescriptor$sub_refs;
typedef struct _jc_java_io_FileDescriptor$sub_nonrefs	_jc_java_io_FileDescriptor$sub_nonrefs;
typedef struct _jc_java_io_FileDescriptor$refs	_jc_java_io_FileDescriptor$refs;
typedef struct _jc_java_io_FileDescriptor$nonrefs	_jc_java_io_FileDescriptor$nonrefs;
typedef struct _jc_java_io_FileDescriptor$object	_jc_java_io_FileDescriptor$object;

typedef struct _jc_java_io_FileDescriptor$fields_struct	_jc_java_io_FileDescriptor$fields_struct;
typedef const struct _jc_java_io_FileDescriptor$vmethods	_jc_java_io_FileDescriptor$vmethods;
typedef const struct _jc_java_io_FileDescriptor$vtable	_jc_java_io_FileDescriptor$vtable;
typedef const struct _jc_java_io_FileDescriptor$vtype	_jc_java_io_FileDescriptor$vtype;

// Class fields structure
struct _jc_java_io_FileDescriptor$fields_struct {
	struct _jc_java_io_FileDescriptor$object	*err;
	struct _jc_java_io_FileDescriptor$object	*in;
	struct _jc_java_io_FileDescriptor$object	*out;
};
extern _jc_java_io_FileDescriptor$fields_struct _jc_java_io_FileDescriptor$class_fields;

// Constructors
extern void _jc_java_io_FileDescriptor$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_io_FileDescriptor$object *);
extern void _jc_java_io_FileDescriptor$method$_init$1979f2016fb54db9(_jc_env *, struct _jc_java_io_FileDescriptor$object *, struct _jc_object *);

// Virtual methods
extern void _jc_java_io_FileDescriptor$method$sync$fec0b96453a6496a(_jc_env *, struct _jc_java_io_FileDescriptor$object *);
extern jboolean _jc_java_io_FileDescriptor$method$valid$550c6e9b2fef10c9(_jc_env *, struct _jc_java_io_FileDescriptor$object *);

// Virtual method descriptors
extern _jc_method _jc_java_io_FileDescriptor$method_info$sync$fec0b96453a6496a;
extern _jc_method _jc_java_io_FileDescriptor$method_info$valid$550c6e9b2fef10c9;

// Static methods
extern void _jc_java_io_FileDescriptor$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_io_FileDescriptor$vmethods {
	void	(*sync$fec0b96453a6496a)(_jc_env *, struct _jc_java_io_FileDescriptor$object *);
	jboolean	(*valid$550c6e9b2fef10c9)(_jc_env *, struct _jc_java_io_FileDescriptor$object *);
};

// Vtable
struct _jc_java_io_FileDescriptor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_FileDescriptor$vmethods	java_io_FileDescriptor;
};

// Vtype
struct _jc_java_io_FileDescriptor$vtype {
	_jc_type			type;
	_jc_java_io_FileDescriptor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_FileDescriptor$sub_refs {
	struct _jc_object	*channel;
};

// Reference instance fields (object)
struct _jc_java_io_FileDescriptor$refs {
    _jc_java_io_FileDescriptor$sub_refs	java_io_FileDescriptor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_FileDescriptor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_FileDescriptor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_FileDescriptor$sub_nonrefs	java_io_FileDescriptor;
};

// Object instance structure
struct _jc_java_io_FileDescriptor$object {
	_jc_java_io_FileDescriptor$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_FileDescriptor$vtype	*vtype;
	_jc_java_io_FileDescriptor$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_FileDescriptor$vtype _jc_java_io_FileDescriptor$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_FileDescriptor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_FileDescriptor$class_object;

#endif	/* _JC_java_io_FileDescriptor_H_ */

==> jc-1.4.6.tar.gz: java/io/FileDescriptor.h <==
// public final class java.io.FileDescriptor

// class file dependencies
// @dep_class 410fd3c919444a2c java_io_FileDescriptor
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_io_FileDescriptor_H_
#define _JC_java_io_FileDescriptor_H_

// Forward structure declarations
struct _jc_java_io_FileDescriptor$object;
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_ByteChannel$object;

// Typedefs
typedef struct _jc_java_io_FileDescriptor$sub_refs	_jc_java_io_FileDescriptor$sub_refs;
typedef struct _jc_java_io_FileDescriptor$sub_nonrefs	_jc_java_io_FileDescriptor$sub_nonrefs;
typedef struct _jc_java_io_FileDescriptor$refs	_jc_java_io_FileDescriptor$refs;
typedef struct _jc_java_io_FileDescriptor$nonrefs	_jc_java_io_FileDescriptor$nonrefs;
typedef struct _jc_java_io_FileDescriptor$object	_jc_java_io_FileDescriptor$object;

typedef struct _jc_java_io_FileDescriptor$fields_struct	_jc_java_io_FileDescriptor$fields_struct;
typedef const struct _jc_java_io_FileDescriptor$vmethods	_jc_java_io_FileDescriptor$vmethods;
typedef const struct _jc_java_io_FileDescriptor$vtable	_jc_java_io_FileDescriptor$vtable;
typedef const struct _jc_java_io_FileDescriptor$vtype	_jc_java_io_FileDescriptor$vtype;

// Class fields structure
struct _jc_java_io_FileDescriptor$fields_struct {
	struct _jc_java_io_FileDescriptor$object	*err;
	struct _jc_java_io_FileDescriptor$object	*in;
	struct _jc_java_io_FileDescriptor$object	*out;
};
extern _jc_java_io_FileDescriptor$fields_struct _jc_java_io_FileDescriptor$class_fields;

// Constructors
extern void _jc_java_io_FileDescriptor$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_io_FileDescriptor$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_FileDescriptor$method$_init$1979f2016fb54db9(_jc_env *, struct _jc_java_io_FileDescriptor$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_io_FileDescriptor$method$sync$fec0b96453a6496a(_jc_env *, struct _jc_java_io_FileDescriptor$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_io_FileDescriptor$method$valid$550c6e9b2fef10c9(_jc_env *, struct _jc_java_io_FileDescriptor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_io_FileDescriptor$method_info$sync$fec0b96453a6496a;
extern _jc_method _jc_java_io_FileDescriptor$method_info$valid$550c6e9b2fef10c9;

// Static methods
extern void _jc_java_io_FileDescriptor$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_io_FileDescriptor$vmethods {
	void	(*sync$fec0b96453a6496a)(_jc_env *, struct _jc_java_io_FileDescriptor$object *) _JC_JCNI_ATTR;
	jboolean	(*valid$550c6e9b2fef10c9)(_jc_env *, struct _jc_java_io_FileDescriptor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_io_FileDescriptor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_FileDescriptor$vmethods	java_io_FileDescriptor;
};

// Vtype
struct _jc_java_io_FileDescriptor$vtype {
	_jc_type			type;
	_jc_java_io_FileDescriptor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_FileDescriptor$sub_refs {
	struct _jc_object	*channel;
};

// Reference instance fields (object)
struct _jc_java_io_FileDescriptor$refs {
    _jc_java_io_FileDescriptor$sub_refs	java_io_FileDescriptor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_FileDescriptor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_FileDescriptor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_FileDescriptor$sub_nonrefs	java_io_FileDescriptor;
};

// Object instance structure
struct _jc_java_io_FileDescriptor$object {
	_jc_java_io_FileDescriptor$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_FileDescriptor$vtype	*vtype;
	_jc_java_io_FileDescriptor$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_FileDescriptor$vtype _jc_java_io_FileDescriptor$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_FileDescriptor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_FileDescriptor$class_object;

#endif	/* _JC_java_io_FileDescriptor_H_ */
